Distru package
===============
This is a simple project that is used to grasp how to publish
Python packages on PyPI. This package is used to generate or read data
from a specific distribution and make some functionality or visualize it.

Installing
============
    pip install distru

